==> net.bluemind.p2.platform-4.9.3879.zip: net/bluemind/eas/backend/bm/contacts/ContactNotificationHandler.java <==
/* BEGIN LICENSE
 * Copyright © Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.eas.backend.bm.contacts;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import io.vertx.core.eventbus.EventBus;
import io.vertx.core.json.JsonObject;
import net.bluemind.addressbook.api.IAddressBookUids;
import net.bluemind.core.container.api.ContainerHierarchyNode;
import net.bluemind.eas.backend.HierarchyNode;
import net.bluemind.eas.exception.CollectionNotFoundException;
import net.bluemind.eas.store.ISyncStorage;
import net.bluemind.hornetq.client.OOPMessage;
import net.bluemind.hornetq.client.OutOfProcessMessageHandler;
import net.bluemind.lib.vertx.VertxPlatform;

public class ContactNotificationHandler implements OutOfProcessMessageHandler {

	private static final Logger logger = LoggerFactory.getLogger(ContactNotificationHandler.class);
	private ISyncStorage store;
	private static final EventBus eb = VertxPlatform.eventBus();

	public ContactNotificationHandler(ISyncStorage ss) {
		this.store = ss;
	}

	@Override
	public void handle(OOPMessage m) {
		logger.debug("contact notification onMsg op: {}", m);

		String domainUid = m.getStringProperty("domainUid");

		if ("global.virt".equals(domainUid)) {
			return;
		}

		String container = m.getStringProperty("container");
		String userUid = m.getStringProperty("userUid");

		try {
			HierarchyNode node = store.getHierarchyNode("ContactNotificationHandler-" + container, domainUid, userUid,
					ContainerHierarchyNode.uidFor(container, IAddressBookUids.TYPE, domainUid));
			eb.publish("eas.collection." + node.collectionId.getValue(), new JsonObject());
		} catch (CollectionNotFoundException e) {
			logger.error(e.getMessage(), e);
		}

	}

}

==> net.bluemind.p2.platform-5.5.3184.zip: net/bluemind/eas/backend/bm/contacts/ContactNotificationHandler.java <==
/* BEGIN LICENSE
 * Copyright © Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.eas.backend.bm.contacts;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import io.vertx.core.eventbus.EventBus;
import io.vertx.core.json.JsonObject;
import net.bluemind.addressbook.api.IAddressBookUids;
import net.bluemind.core.container.api.ContainerHierarchyNode;
import net.bluemind.eas.backend.HierarchyNode;
import net.bluemind.eas.dto.EasBusEndpoints;
import net.bluemind.eas.exception.CollectionNotFoundException;
import net.bluemind.eas.store.ISyncStorage;
import net.bluemind.hornetq.client.OOPMessage;
import net.bluemind.hornetq.client.OutOfProcessMessageHandler;
import net.bluemind.lib.vertx.VertxPlatform;

public class ContactNotificationHandler implements OutOfProcessMessageHandler {

	private static final Logger logger = LoggerFactory.getLogger(ContactNotificationHandler.class);
	private ISyncStorage store;
	private static final EventBus eb = VertxPlatform.eventBus();

	public ContactNotificationHandler(ISyncStorage ss) {
		this.store = ss;
	}

	@Override
	public void handle(OOPMessage m) {
		logger.debug("contact notification onMsg op: {}", m);

		String domainUid = m.getStringProperty("domainUid");

		if ("global.virt".equals(domainUid)) {
			return;
		}

		String container = m.getStringProperty("container");
		String userUid = m.getStringProperty("userUid");
		Thread.ofVirtual().name("eas-contact-dispatch").start(() -> propagateEvent(domainUid, container, userUid));
	}

	private void propagateEvent(String domainUid, String container, String userUid) {
		try {
			HierarchyNode node = store.getHierarchyNode("ContactNotificationHandler-" + container, domainUid, userUid,
					ContainerHierarchyNode.uidFor(container, IAddressBookUids.TYPE, domainUid));
			eb.publish(EasBusEndpoints.SYNC_COLLECTION + node.collectionId.getValue(), new JsonObject());
		} catch (CollectionNotFoundException e) {
			logger.error(e.getMessage());
		}

	}

}
